XmlEvent class

Inheritance

Constructors

XmlEvent(XmlState state, {String? key = "", String? value = ""})

Properties

fired ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ XmlState
getter/setter pair
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited