XmlProcessor<T> class abstract

Implementers

Constructors

XmlProcessor()

Properties

currentTag ↔ String?
getter/setter pair
element ↔ T?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopedTag ↔ String?
getter/setter pair
tagName ↔ String?
getter/setter pair

Methods

isOnCurrentTag() → bool
isScope() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAttribute(String? key, String? value) → void
onCharacters(String? text) → void
onClosedTag(String? tag) → void
onOpenTag(String? tag) → void
onProcess() → Stream<T?>
onScopedCharacters(String? text) → void
onScopedTag(String? tag) → void
shouldAttribute(String? key, String? value) → void
shouldCharacters(String? text) → void
shouldClosedTag(String? tag) → void
shouldOpenTag(String? tag) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited