XmlStreamer class

Constructors

XmlStreamer(String? raw, {bool trimSpaces = true})
XmlStreamer.fromStream(Stream<List<int>>? stream)

Properties

hashCode → int
The hash code for this object.
no setterinherited
raw ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
special_char ↔ String?
getter/setter pair
stream ↔ Stream<List<int>>?
getter/setter pair
trimSpaces ↔ bool
getter/setter pair

Methods

addCharToValue(XmlEvent event, String ch) → XmlEvent
createAndAddXmlEvent(XmlState state) → XmlEvent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Stream<XmlEvent>
shutdown() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

EMPTY → const String